@@ -41,6 +41,7 @@ macro_rules! convert_error_to_string {
     };
 }
 
+#[allow(dead_code)]
 #[derive(Clone)]
 pub struct ZProcess {
     pub pid: i32,
@@ -201,26 +202,23 @@ impl ZProcess {
     #[cfg(target_os = "linux")]
     pub fn update_delay(&mut self, client: &Option<Client>) {
         debug!("Getting Task Stats for {}", self.pid);
-        match client {
-            Some(c) => {
-                let stats_result = c.pid_stats(self.pid as u32);
-                match stats_result {
-                    Ok(s) => {
-                        self.prev_io_delay = self.io_delay;
-                        self.prev_swap_delay = self.swap_delay;
-                        self.io_delay = s.delays.blkio.delay_total;
-                        self.swap_delay = s.delays.swapin.delay_total;
-                        debug!(
-                            "Pid: {} io_delay: {} swap_delay: {}",
-                            self.pid,
-                            self.io_delay.as_secs(),
-                            self.swap_delay.as_secs()
-                        );
-                    }
-                    Err(_) => debug!("Couldn't get stats for {}", self.pid),
+        if let Some(c) = client {
+            let stats_result = c.pid_stats(self.pid as u32);
+            match stats_result {
+                Ok(s) => {
+                    self.prev_io_delay = self.io_delay;
+                    self.prev_swap_delay = self.swap_delay;
+                    self.io_delay = s.delays.blkio.delay_total;
+                    self.swap_delay = s.delays.swapin.delay_total;
+                    debug!(
+                        "Pid: {} io_delay: {} swap_delay: {}",
+                        self.pid,
+                        self.io_delay.as_secs(),
+                        self.swap_delay.as_secs()
+                    );
                 }
+                Err(_) => debug!("Couldn't get stats for {}", self.pid),
             }
-            None => {}
         }
     }
 
@@ -265,9 +263,7 @@ impl ZProcess {
         sortfield: ProcessTableSortBy,
     ) -> fn(&Self, &Self, &Duration) -> Ordering {
         match sortfield {
-            ProcessTableSortBy::Cpu => {
-                |pa, pb, _tick| pa.cpu_usage.partial_cmp(&pb.cpu_usage).unwrap_or(Equal)
-            }
+            ProcessTableSortBy::Cpu => |pa, pb, _tick| pa.cpu_usage.total_cmp(&pb.cpu_usage),
             ProcessTableSortBy::Mem => |pa, pb, _tick| pa.memory.cmp(&pb.memory),
             ProcessTableSortBy::MemPerc => |pa, pb, _tick| pa.memory.cmp(&pb.memory),
             ProcessTableSortBy::User => |pa, pb, _tick| pa.user_name.cmp(&pb.user_name),
@@ -276,20 +272,16 @@ impl ZProcess {
                 |pa, pb, _tick| pa.status.to_single_char().cmp(pb.status.to_single_char())
             }
             ProcessTableSortBy::Priority => |pa, pb, _tick| pa.priority.cmp(&pb.priority),
-            ProcessTableSortBy::Nice => {
-                |pa, pb, _tick| pa.priority.partial_cmp(&pb.nice).unwrap_or(Equal)
-            }
+            ProcessTableSortBy::Nice => |pa, pb, _tick| pa.nice.cmp(&pb.nice),
             ProcessTableSortBy::Virt => |pa, pb, _tick| pa.virtual_memory.cmp(&pb.virtual_memory),
             ProcessTableSortBy::Cmd => |pa, pb, _tick| pa.name.cmp(&pb.name),
             ProcessTableSortBy::DiskRead => |pa, pb, tick| {
                 pa.get_read_bytes_sec(tick)
-                    .partial_cmp(&pb.get_read_bytes_sec(tick))
-                    .unwrap_or(Equal)
+                    .total_cmp(&pb.get_read_bytes_sec(tick))
             },
             ProcessTableSortBy::DiskWrite => |pa, pb, tick| {
                 pa.get_write_bytes_sec(tick)
-                    .partial_cmp(&pb.get_write_bytes_sec(tick))
-                    .unwrap_or(Equal)
+                    .total_cmp(&pb.get_write_bytes_sec(tick))
             },
         }
     }
