@@ -5,8 +5,8 @@ use super::style::{max_style, ok_style, MAX_COLOR, OK_COLOR};
 use crate::float_to_byte_string;
 use crate::metrics::histogram::{HistogramKind, View};
 use crate::metrics::CPUTimeApp;
-use crate::renderer::{percent_of, split_left_right_pane, Render, ZBackend};
-use byte_unit::{Byte, ByteUnit};
+use crate::renderer::{percent_of, split_left_right_pane, Render};
+use byte_unit::{Byte, Unit};
 use ratatui::layout::{Constraint, Direction, Layout, Rect};
 use ratatui::style::{Color, Modifier, Style};
 use ratatui::text::{Line, Span};
@@ -42,9 +42,25 @@ fn cpu_title<'a>(app: &'a CPUTimeApp, histogram: &'a [u64]) -> Line<'a> {
             .map(|s| format!("{: >3.0}", s.current_temp))
             .collect::<Vec<String>>()
             .join(",");
-        format!(" TEMP [{:}°C]", t)
+
+        let hot_threshold = 70_f64;
+        let cold_threshold = 40_f64;
+        let numbers_txt = format!("{t:}°C");
+        let max_temp = app
+            .sensors
+            .iter()
+            .map(|s| s.current_temp as f64)
+            .fold(f64::MIN, f64::max);
+
+        if max_temp > hot_threshold {
+            Span::styled(numbers_txt, max_style())
+        } else if max_temp < cold_threshold {
+            Span::styled(numbers_txt, Style::default().fg(Color::Cyan))
+        } else {
+            Span::raw(numbers_txt)
+        }
     } else {
-        String::from("")
+        Span::raw(String::from(""))
     };
     Line::from(vec![
         Span::raw("CPU ["),
@@ -57,20 +73,21 @@ fn cpu_title<'a>(app: &'a CPUTimeApp, histogram: &'a [u64]) -> Line<'a> {
             },
         ),
         Span::raw("]"),
-        Span::raw(temp),
+        Span::raw(" TEMP ["),
+        temp,
+        Span::raw("]"),
         Span::raw(" MEAN ["),
         Span::styled(
-            format!("{: >3.2}%", mean,),
+            format!("{mean: >3.2}%",),
             if mean > 90.0 { max_style() } else { ok_style() },
         ),
         Span::raw("] PEAK ["),
         Span::styled(
-            format!("{: >3.2}%", peak,),
+            format!("{peak: >3.2}%",),
             if peak > 90 { max_style() } else { ok_style() },
         ),
         Span::raw(format!(
-            "] TOP [{} - {} - {}]",
-            top_pid, top_process_name, top_process_amt
+            "] TOP [{top_pid} - {top_process_name} - {top_process_amt}]"
         )),
     ])
 }
@@ -92,8 +109,8 @@ fn mem_title(app: &CPUTimeApp) -> Line {
         Span::styled(
             format!(
                 "{} / {} - {:}%",
-                float_to_byte_string!(app.mem_utilization as f64, ByteUnit::KB),
-                float_to_byte_string!(app.mem_total as f64, ByteUnit::KB),
+                float_to_byte_string!(app.mem_utilization as f64, Unit::KB),
+                float_to_byte_string!(app.mem_total as f64, Unit::KB),
                 mem
             ),
             if mem > 95 { max_style() } else { ok_style() },
@@ -102,8 +119,8 @@ fn mem_title(app: &CPUTimeApp) -> Line {
         Span::styled(
             format!(
                 "{} / {} - {:}%",
-                float_to_byte_string!(app.swap_utilization as f64, ByteUnit::KB),
-                float_to_byte_string!(app.swap_total as f64, ByteUnit::KB),
+                float_to_byte_string!(app.swap_utilization as f64, Unit::KB),
+                float_to_byte_string!(app.swap_total as f64, Unit::KB),
                 swp,
             ),
             if swp > 20 { max_style() } else { ok_style() },
@@ -113,7 +130,7 @@ fn mem_title(app: &CPUTimeApp) -> Line {
     ])
 }
 
-fn render_cpu_histogram(app: &CPUTimeApp, area: Rect, f: &mut Frame<'_, ZBackend>, view: &View) {
+fn render_cpu_histogram(app: &CPUTimeApp, area: Rect, f: &mut Frame<'_>, view: &View) {
     let h = match app.histogram_map.get_zoomed(&HistogramKind::Cpu, view) {
         Some(h) => h,
         None => return,
@@ -127,7 +144,7 @@ fn render_cpu_histogram(app: &CPUTimeApp, area: Rect, f: &mut Frame<'_, ZBackend
         .render(f, area);
 }
 
-fn render_memory_histogram(app: &CPUTimeApp, area: Rect, f: &mut Frame<'_, ZBackend>, view: &View) {
+fn render_memory_histogram(app: &CPUTimeApp, area: Rect, f: &mut Frame<'_>, view: &View) {
     let h = match app.histogram_map.get_zoomed(&HistogramKind::Mem, view) {
         Some(h) => h,
         None => return,
@@ -141,7 +158,7 @@ fn render_memory_histogram(app: &CPUTimeApp, area: Rect, f: &mut Frame<'_, ZBack
         .render(f, area);
 }
 
-fn render_cpu_bars(app: &CPUTimeApp, area: Rect, f: &mut Frame<'_, ZBackend>, style: &Style) {
+fn render_cpu_bars(app: &CPUTimeApp, area: Rect, f: &mut Frame<'_>, style: &Style) {
     let cpus = app.cpus.to_owned();
     if cpus.is_empty() {
         return;
@@ -176,7 +193,7 @@ fn render_cpu_bars(app: &CPUTimeApp, area: Rect, f: &mut Frame<'_, ZBackend>, st
 
         let cols = 4;
 
-        let nrows = ((cpus.len() as u16 + cols - 1) / cols) as usize;
+        let nrows = (cpus.len() as u16).div_ceil(cols) as usize;
 
         let mut items = vec![];
         for i in 0..nrows {
@@ -185,10 +202,10 @@ fn render_cpu_bars(app: &CPUTimeApp, area: Rect, f: &mut Frame<'_, ZBackend>, st
                 .step_by(nrows)
                 .take(cols.into())
                 .for_each(|(label, load)| {
-                    items.push(Span::raw(format!("{:<2} ", label)));
+                    items.push(Span::raw(format!("{label:<2} ")));
                     let color = if *load < 90 { OK_COLOR } else { MAX_COLOR };
                     items.push(Span::styled(
-                        format!("{:3}", load),
+                        format!("{load:3}"),
                         Style::default().fg(color),
                     ));
                     items.push(Span::raw("% "));
@@ -269,7 +286,7 @@ fn render_cpu_bars(app: &CPUTimeApp, area: Rect, f: &mut Frame<'_, ZBackend>, st
 pub fn render_cpu(
     app: &CPUTimeApp,
     area: Rect,
-    f: &mut Frame<'_, ZBackend>,
+    f: &mut Frame<'_>,
     view: View,
     border_style: Style,
 ) {
