@@ -1,11 +1,11 @@
 /**
  * Copyright 2019-2022, Benjamin Vaisvil and the zenith contributors
  */
-use super::{split_left_right_pane, Render, ZBackend};
+use super::{split_left_right_pane, Render};
 use crate::float_to_byte_string;
 use crate::metrics::histogram::{HistogramKind, View};
 use crate::metrics::CPUTimeApp;
-use byte_unit::{Byte, ByteUnit};
+use byte_unit::{Byte, Unit};
 use ratatui::layout::{Constraint, Direction, Layout, Rect};
 use ratatui::style::{Color, Style};
 use ratatui::text::Span;
@@ -16,7 +16,7 @@ use std::borrow::Cow;
 pub fn render_net(
     app: &CPUTimeApp,
     area: Rect,
-    f: &mut Frame<'_, ZBackend>,
+    f: &mut Frame<'_>,
     view: View,
     border_style: Style,
 ) {
@@ -29,7 +29,7 @@ pub fn render_net(
 
     let net_up = float_to_byte_string!(
         app.net_out as f64 / app.histogram_map.tick.as_secs_f64(),
-        ByteUnit::B
+        Unit::B
     );
     let h_out = match app.histogram_map.get_zoomed(&HistogramKind::NetTx, &view) {
         Some(h) => h,
@@ -40,12 +40,12 @@ pub fn render_net(
         Some(x) => *x,
         None => 1,
     };
-    let up_max_bytes = float_to_byte_string!(up_max as f64, ByteUnit::B);
+    let up_max_bytes = float_to_byte_string!(up_max as f64, Unit::B);
 
     Sparkline::default()
         .block(
             Block::default()
-                .title(format!("↑ [{:^10}/s] PEAK [{:^10}/s]", net_up, up_max_bytes).as_str()),
+                .title(format!("↑ [{net_up:^10}/s] PEAK [{up_max_bytes:^10}/s]").as_str()),
         )
         .data(h_out.data())
         .style(Style::default().fg(Color::LightYellow))
@@ -54,7 +54,7 @@ pub fn render_net(
 
     let net_down = float_to_byte_string!(
         app.net_in as f64 / app.histogram_map.tick.as_secs_f64(),
-        ByteUnit::B
+        Unit::B
     );
     let h_in = match app.histogram_map.get_zoomed(&HistogramKind::NetRx, &view) {
         Some(h) => h,
@@ -65,11 +65,11 @@ pub fn render_net(
         Some(x) => *x,
         None => 1,
     };
-    let down_max_bytes = float_to_byte_string!(down_max as f64, ByteUnit::B);
+    let down_max_bytes = float_to_byte_string!(down_max as f64, Unit::B);
     Sparkline::default()
         .block(
             Block::default()
-                .title(format!("↓ [{:^10}/s] PEAK [{:^10}/s]", net_down, down_max_bytes).as_str()),
+                .title(format!("↓ [{net_down:^10}/s] PEAK [{down_max_bytes:^10}/s]").as_str()),
         )
         .data(h_in.data())
         .style(Style::default().fg(Color::LightMagenta))
