@@ -1,11 +1,11 @@
 /**
  * Copyright 2019-2022, Benjamin Vaisvil and the zenith contributors
  */
-use super::{percent_of, Render, ZBackend};
+use super::{percent_of, Render};
 use crate::float_to_byte_string;
 use crate::metrics::zprocess::{ProcessStatusExt, ZProcess};
 use crate::metrics::{CPUTimeApp, ProcessTableSortOrder};
-use byte_unit::{Byte, ByteUnit};
+use byte_unit::{Byte, Unit};
 use chrono::prelude::DateTime;
 use chrono::Local;
 use ratatui::layout::{Constraint, Direction, Layout, Rect};
@@ -21,7 +21,7 @@ pub fn render_process_table(
     process_table: &[i32],
     area: Rect,
     process_table_start: usize,
-    f: &mut Frame<'_, ZBackend>,
+    f: &mut Frame<'_>,
     border_style: Style,
     show_paths: bool,
     show_find: bool,
@@ -51,7 +51,107 @@ pub fn render_process_table(
         return highlighted_process; // not enough space to draw anything
     }
 
-    let rows: Vec<Row> = procs
+    let rows: Vec<Row> = render_rows(
+        app,
+        procs,
+        process_table_start,
+        display_height,
+        show_paths,
+        highlighted_row,
+    );
+
+    let mut header = vec![
+        format!("{:<width$}", "PID", width = app.max_pid_len + 1),
+        String::from("USER       "),
+        String::from("P   "),
+        String::from("N   "),
+        String::from("CPU%  "),
+        String::from("MEM%  "),
+        String::from("MEM     "),
+        String::from("VIRT     "),
+        String::from("S "),
+        String::from("READ/s   "),
+        String::from("WRITE/s  "),
+    ];
+    #[cfg(target_os = "linux")]
+    header.push(String::from("IOWAIT% "));
+    #[cfg(feature = "nvidia")]
+    header.push(String::from("GPU% "));
+    #[cfg(feature = "nvidia")]
+    header.push(String::from("FB%  "));
+    //figure column widths
+    let mut widths = Vec::with_capacity(header.len() + 1);
+    let mut used_width = 0;
+    for item in &header {
+        let len = item.len() as u16;
+        widths.push(Constraint::Length(len));
+        used_width += len;
+    }
+    let cmd_width = f.area().width.saturating_sub(used_width).saturating_sub(3);
+    let cmd_header = format!("{:<width$}", "CMD", width = cmd_width as usize);
+    widths.push(Constraint::Min(cmd_width));
+    header.push(cmd_header);
+
+    header[app.psortby as usize].pop();
+    let sort_ind = match app.psortorder {
+        ProcessTableSortOrder::Ascending => '↑',
+        ProcessTableSortOrder::Descending => '↓',
+    };
+    header[app.psortby as usize].insert(0, sort_ind); //sort column indicator
+    let header_row: Vec<Cell> = header
+        .iter()
+        .enumerate()
+        .map(|(i, c)| {
+            if i == app.psortby as usize {
+                Cell::from(c.as_str()).style(
+                    Style::default()
+                        .bg(Color::Gray)
+                        .fg(Color::Black)
+                        .add_modifier(Modifier::BOLD),
+                )
+            } else {
+                Cell::from(c.as_str())
+            }
+        })
+        .collect();
+    let title = if show_find {
+        format!("[ESC] Clear, Find: {filter:}")
+    } else if !filter.is_empty() {
+        format!("Filtered Results: {filter:}, [/] to change/clear")
+    } else {
+        format!(
+            "Tasks [{:}] Threads [{:}]  Navigate [↑/↓] Sort Col [,/.] Asc/Dec [;] Filter [/]",
+            app.processes.len(),
+            app.threads_total
+        )
+    };
+
+    Table::new(rows, widths)
+        .block(
+            Block::default()
+                .borders(Borders::ALL)
+                .border_style(border_style)
+                .title(Span::styled(title, border_style)),
+        )
+        .column_spacing(0)
+        .header(
+            Row::new(header_row)
+                .style(Style::default().bg(Color::DarkGray))
+                .bottom_margin(0),
+        )
+        .render(f, area);
+    highlighted_process
+}
+
+fn render_rows<'a>(
+    app: &CPUTimeApp,
+    procs: Vec<&'a ZProcess>,
+    process_table_start: usize,
+    display_height: usize,
+    show_paths: bool,
+    highlighted_row: usize,
+) -> Vec<Row<'a>> {
+    procs
         .iter()
         .enumerate()
         .skip(process_table_start)
@@ -72,13 +172,10 @@ pub fn render_process_table(
             };
             let mut cpu_usage =
                 set_process_row_style(p.pid, app.top_pids.cpu.pid, format!("{:>5.1}", p.cpu_usage));
-            match &app.cum_cpu_process {
-                Some(top) => {
-                    if top.pid == p.pid {
-                        cpu_usage = cpu_usage.style(Style::default().fg(Color::Magenta));
-                    }
+            if let Some(top) = &app.cum_cpu_process {
+                if top.pid == p.pid {
+                    cpu_usage = cpu_usage.style(Style::default().fg(Color::Magenta));
                 }
-                None => (),
             };
 
             let mut row = vec![
@@ -97,7 +194,7 @@ pub fn render_process_table(
                     app.top_pids.mem.pid,
                     format!(
                         "{:>8}",
-                        float_to_byte_string!(p.memory as f64, ByteUnit::KB).replace('B', "")
+                        float_to_byte_string!(p.memory as f64, Unit::KB).replace('B', "")
                     ),
                 ),
                 set_process_row_style(
@@ -105,8 +202,7 @@ pub fn render_process_table(
                     app.top_pids.virt.pid,
                     format!(
                         "{:>8}",
-                        float_to_byte_string!(p.virtual_memory as f64, ByteUnit::KB)
-                            .replace('B', "")
+                        float_to_byte_string!(p.virtual_memory as f64, Unit::KB).replace('B', "")
                     ),
                 ),
                 Cell::from(format!("{:1}", p.status.to_single_char())),
@@ -117,7 +213,7 @@ pub fn render_process_table(
                         "{:>8}",
                         float_to_byte_string!(
                             p.get_read_bytes_sec(&app.histogram_map.tick),
-                            ByteUnit::B
+                            Unit::B
                         )
                         .replace('B', "")
                     ),
@@ -129,7 +225,7 @@ pub fn render_process_table(
                         "{:>8}",
                         float_to_byte_string!(
                             p.get_write_bytes_sec(&app.histogram_map.tick),
-                            ByteUnit::B
+                            Unit::B
                         )
                         .replace('B', "")
                     ),
@@ -170,96 +266,13 @@ pub fn render_process_table(
                 row
             }
         })
-        .collect();
-
-    let mut header = vec![
-        format!("{:<width$}", "PID", width = app.max_pid_len + 1),
-        String::from("USER       "),
-        String::from("P   "),
-        String::from("N   "),
-        String::from("CPU%  "),
-        String::from("MEM%  "),
-        String::from("MEM     "),
-        String::from("VIRT     "),
-        String::from("S "),
-        String::from("READ/s   "),
-        String::from("WRITE/s  "),
-    ];
-    #[cfg(target_os = "linux")]
-    header.push(String::from("IOWAIT% "));
-    #[cfg(feature = "nvidia")]
-    header.push(String::from("GPU% "));
-    #[cfg(feature = "nvidia")]
-    header.push(String::from("FB%  "));
-    //figure column widths
-    let mut widths = Vec::with_capacity(header.len() + 1);
-    let mut used_width = 0;
-    for item in &header {
-        let len = item.len() as u16;
-        widths.push(Constraint::Length(len));
-        used_width += len;
-    }
-    let cmd_width = f.size().width.saturating_sub(used_width).saturating_sub(3);
-    let cmd_header = format!("{:<width$}", "CMD", width = cmd_width as usize);
-    widths.push(Constraint::Min(cmd_width));
-    header.push(cmd_header);
-
-    header[app.psortby as usize].pop();
-    let sort_ind = match app.psortorder {
-        ProcessTableSortOrder::Ascending => '↑',
-        ProcessTableSortOrder::Descending => '↓',
-    };
-    header[app.psortby as usize].insert(0, sort_ind); //sort column indicator
-    let header_row: Vec<Cell> = header
-        .iter()
-        .enumerate()
-        .map(|(i, c)| {
-            if i == app.psortby as usize {
-                Cell::from(c.as_str()).style(
-                    Style::default()
-                        .bg(Color::Gray)
-                        .fg(Color::Black)
-                        .add_modifier(Modifier::BOLD),
-                )
-            } else {
-                Cell::from(c.as_str())
-            }
-        })
-        .collect();
-    let title = if show_find {
-        format!("[ESC] Clear, Find: {:}", filter)
-    } else if !filter.is_empty() {
-        format!("Filtered Results: {:}, [/] to change/clear", filter)
-    } else {
-        format!(
-            "Tasks [{:}] Threads [{:}]  Navigate [↑/↓] Sort Col [,/.] Asc/Dec [;] Filter [/]",
-            app.processes.len(),
-            app.threads_total
-        )
-    };
-
-    Table::new(rows)
-        .block(
-            Block::default()
-                .borders(Borders::ALL)
-                .border_style(border_style)
-                .title(Span::styled(title, border_style)),
-        )
-        .widths(widths.as_slice())
-        .column_spacing(0)
-        .header(
-            Row::new(header_row)
-                .style(Style::default().bg(Color::DarkGray))
-                .bottom_margin(0),
-        )
-        .render(f, area);
-    highlighted_process
+        .collect()
 }
 
 pub fn render_process(
     app: &CPUTimeApp,
     layout: Rect,
-    f: &mut Frame<'_, ZBackend>,
+    f: &mut Frame<'_>,
     border_style: Style,
     process_message: &Option<String>,
     p: &ZProcess,
@@ -275,7 +288,7 @@ pub fn render_process(
         .constraints([Constraint::Length(2), Constraint::Min(1)].as_ref())
         .split(layout);
 
-    let title = format!("(b)ack (n)ice (p)riority 0 (s)uspend (r)esume (k)ill [SIGKILL] (t)erminate [SIGTERM] {:} {: >width$}", 
+    let title = format!("(b)ack (n)ice (p)riority 0 (s)uspend (r)esume (k)ill [SIGKILL] (t)erminate [SIGTERM] {:} {: >width$}",
                         process_message.as_ref().unwrap_or(&String::from("")), "", width = layout.width as usize);
 
     Block::default()
@@ -368,10 +381,7 @@ pub fn render_process(
         Line::from(vec![
             Span::raw("Total Memory:          "),
             Span::styled(
-                format!(
-                    "{:>10}",
-                    float_to_byte_string!(p.memory as f64, ByteUnit::KB)
-                ),
+                format!("{:>10}", float_to_byte_string!(p.memory as f64, Unit::KB)),
                 rhs_style,
             ),
         ]),
@@ -380,11 +390,8 @@ pub fn render_process(
             Span::styled(
                 format!(
                     "{:>10} {:}/s",
-                    float_to_byte_string!(p.read_bytes as f64, ByteUnit::B),
-                    float_to_byte_string!(
-                        p.get_read_bytes_sec(&app.histogram_map.tick),
-                        ByteUnit::B
-                    )
+                    float_to_byte_string!(p.read_bytes as f64, Unit::B),
+                    float_to_byte_string!(p.get_read_bytes_sec(&app.histogram_map.tick), Unit::B)
                 ),
                 rhs_style,
             ),
@@ -394,11 +401,8 @@ pub fn render_process(
             Span::styled(
                 format!(
                     "{:>10} {:}/s",
-                    float_to_byte_string!(p.write_bytes as f64, ByteUnit::B),
-                    float_to_byte_string!(
-                        p.get_write_bytes_sec(&app.histogram_map.tick),
-                        ByteUnit::B
-                    )
+                    float_to_byte_string!(p.write_bytes as f64, Unit::B),
+                    float_to_byte_string!(p.get_write_bytes_sec(&app.histogram_map.tick), Unit::B)
                 ),
                 rhs_style,
             ),
